<?xml version="1.0" encoding="windows-1251"?>

<xsl:stylesheet
	version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
>

<!--        -->

	<xsl:variable name="start_year">2002</xsl:variable>
	<xsl:variable name="start_month">2</xsl:variable>

	<xsl:template match="month">
		<table cellpadding="4" cellspacing="3" width="100%">
			<tr>
				<td
					bgcolor="white"
					align="center"
					width="16%"
					class="txt"
				>
					<xsl:call-template name="prev_month"/>
				</td>

				<td
					bgcolor="white"
					align="center"
					colspan="5"
					width="68%"
				>
					<xsl:choose>
						<xsl:when test="week/*/@in">
							<strong>
							<xsl:call-template name="month_year_link"/>
							</strong>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="month_year_link"/>
						</xsl:otherwise>
					</xsl:choose>

				</td>

				<td bgcolor="" align="center" width="16%">
					<xsl:call-template name="next_month"/>
				</td>
			</tr>

			<tr>
				<xsl:apply-templates select="weekdays"/>
			</tr>

			<xsl:for-each select="week">
				<tr>
					<xsl:call-template name="week"/>
				</tr>
			</xsl:for-each>

		</table>
	</xsl:template>

<!--     -->

	<xsl:template name="prev_month">
		<xsl:choose>
			<xsl:when
				test="
					month_year/@prev_year &lt; $start_year
				"
			>
				&lt;&lt;
			</xsl:when>

			<xsl:otherwise>
				<xsl:choose>
					<xsl:when
						test="
							month_year/@prev_month &lt; $start_month and 
							month_year/@prev_year = $start_year
						"
					>
						&lt;&lt;
					</xsl:when>
					<xsl:otherwise>
						<a
							href="{month_year/@prev_year}-{month_year/@prev_month}.html"
							style="text-decoration: none;"
						>
							&lt;&lt;
						</a>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

<!--     -->

	<xsl:template name="next_month">
		<xsl:choose>
			<xsl:when test="week/*/@in">
				&gt;&gt;
			</xsl:when>

			<xsl:otherwise>
				<a
					href="{month_year/@next_year}-{month_year/@next_month}.html"
					style="text-decoration: none;"
				>
					&gt;&gt;
				</a>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

<!--     -->

	<xsl:template name="month_year_link">
		<xsl:choose>
			<xsl:when test="month_year/@hit">
				<xsl:call-template name="month_year"/>
			</xsl:when>
			
			<xsl:otherwise>
				<a href="{month_year/@year}-{month_year/@month}.html">
					<xsl:call-template name="month_year"/>
				</a>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

<!--     -->

	<xsl:template name="month_year">
		<xsl:value-of select="month_year/@month_title"/>
		<xsl:text> </xsl:text>
		<xsl:value-of select="month_year/@year"/>
	</xsl:template>

<!--    -->

	<xsl:template match="weekdays">
		<xsl:for-each select="day">
			<td
				align="center"
				width="16%"
				bgcolor="#eeeeee"
			>
				<xsl:choose>
					<xsl:when test="position() != 7">
						<xsl:value-of select="@title"/>
					</xsl:when>
					<xsl:otherwise>
						<span style="color: red">
							<xsl:value-of select="@title"/>
						</span>
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</xsl:for-each>
	</xsl:template>

<!--    -->

	<xsl:template name="week">
		<xsl:for-each select="day">
			<td align="center" width="16%">
				<xsl:attribute name="bgcolor">
					<xsl:choose>
						<xsl:when test="@in">
							#ffcc00
						</xsl:when>
						<xsl:otherwise>
							white
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>

				<xsl:choose>
					<xsl:when test="position() != 7">
						<xsl:call-template name="day"/>
					</xsl:when>
					<xsl:otherwise>
						<span style="color: red">
							<xsl:call-template name="day"/>
						</span>
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</xsl:for-each>
	</xsl:template>

<!--   -->

	<xsl:template name="day">

		<xsl:choose>
			<xsl:when test="@hit">
				<strong><xsl:call-template name="day_value"/></strong>
			</xsl:when>

			<xsl:otherwise>
				<xsl:call-template name="no_hit"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

<!--    -->

	<xsl:template name="no_hit">

		<xsl:choose>
			<xsl:when test="@f">
				<a href="{//*/@year}-{//*/@month}-{@d}.html">
					<xsl:call-template name="day_value"/>
				</a>
			</xsl:when>

			<xsl:otherwise>
				<xsl:call-template name="day_value"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<xsl:template name="day_value">

		<xsl:choose>
			<xsl:when test="@d = 0"/>

			<xsl:when test="@d > 9">
				<xsl:value-of select="@d"/>
			</xsl:when>

			<xsl:otherwise>
				<xsl:text>0</xsl:text><xsl:value-of select="@d"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

</xsl:stylesheet>